import openmc
import numpy as np
import os
import pandas as pd

# list of foil types
_foil_list = ['nb93', 'in115', 'au197']
# openmc model foil cell ids
_foil_cells = [301, 302, 303, 304, 305, 306, 307, 308, 309, 310, 311]
# foil cell volumes per group
_detector_volume = 4.*4*1.
_detector_cells = [303, 305, 307, 309]

def get_openmc_tally(statepoint_file: str, tally_name: str):

    # enter the right folder according to the simulation type, read the openmc statepoint file and convert to dataframe
    try:
        os.chdir('results')
        sp = openmc.StatePoint(statepoint_file)
        tally = sp.get_tally(name=tally_name).get_pandas_dataframe()
        os.chdir('..')
        return tally
    except FileNotFoundError:
        pass


def postprocess_openmc_foils(tally_dataframe):

    df = tally_dataframe.loc[(tally_dataframe['particle'] == 'neutron')]

    df = df[df['cell'].isin(_foil_cells)]
    df['mean'] = df['mean'] / _detector_volume
    df['std. dev.'] = df['std. dev.'] / _detector_volume

    return df[['cell', 'mean', 'std. dev.']]


def postprocess_openmc_spectrum(tally_dataframe, cell):

    df = tally_dataframe.loc[(
        tally_dataframe['particle'] == 'neutron')]

    df = df.loc[(df['cell'] == cell)]
    df['mean'] = df['mean'] / _detector_volume
    df['std. dev.'] = df['std. dev.'] / _detector_volume

    return df[['energy low [eV]', 'energy high [eV]', 'mean', 'std. dev.']]


# postprocess and write csv files
try:
    for foil in _foil_list:
        tdf = get_openmc_tally('statepoint.100.h5', f'{foil}_irdff_rr')
        postprocess_openmc_foils(tdf).to_csv(f'reaction_rates_{foil}.csv')
    for cell in _detector_cells:
        position = cell - 300
        tdf = get_openmc_tally('statepoint.100.h5', 'detector_nspectrum')
        postprocess_openmc_spectrum(tdf, cell).to_csv(f'energy_spectrum_{position}.csv')
except:
    pass
